@@ -1,4 +1,5 @@
 /* This file is part of Clementine.
+   Copyright 2010, David Sansome <me@davidsansome.com>
 
    Clementine is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -17,9 +18,9 @@
 #ifndef DELETEFILES_H
 #define DELETEFILES_H
 
-#include <QObject>
+#include <memory>
 
-#include <boost/shared_ptr.hpp>
+#include <QObject>
 
 #include "song.h"
 
@@ -30,7 +31,7 @@ class DeleteFiles : public QObject {
   Q_OBJECT
 
 public:
-  DeleteFiles(TaskManager* task_manager, boost::shared_ptr<MusicStorage> storage);
+  DeleteFiles(TaskManager* task_manager, std::shared_ptr<MusicStorage> storage);
   ~DeleteFiles();
 
   static const int kBatchSize;
@@ -48,7 +49,7 @@ private:
   QThread* thread_;
   QThread* original_thread_;
   TaskManager* task_manager_;
-  boost::shared_ptr<MusicStorage> storage_;
+  std::shared_ptr<MusicStorage> storage_;
 
   SongList songs_;
 
