@@ -18,8 +18,13 @@
 #ifndef MERGEDPROXYMODEL_H
 #define MERGEDPROXYMODEL_H
 
+#include <functional>
+
 #include <QAbstractProxyModel>
 
+using std::placeholders::_1;
+using std::placeholders::_2;
+
 #include <boost/multi_index_container.hpp>
 #include <boost/multi_index/member.hpp>
 #include <boost/multi_index/ordered_index.hpp>
