@@ -18,12 +18,12 @@
 #ifndef ORGANISE_H
 #define ORGANISE_H
 
+#include <memory>
+
 #include <QBasicTimer>
 #include <QObject>
 #include <QTemporaryFile>
 
-#include <boost/shared_ptr.hpp>
-
 #include "organiseformat.h"
 #include "transcoder/transcoder.h"
 
@@ -35,7 +35,7 @@ class Organise : public QObject {
 
 public:
   Organise(TaskManager* task_manager,
-           boost::shared_ptr<MusicStorage> destination,
+           std::shared_ptr<MusicStorage> destination,
            const OrganiseFormat& format, bool copy, bool overwrite,
            const QStringList& files, bool eject_after);
 
@@ -78,7 +78,7 @@ private:
   QThread* original_thread_;
   TaskManager* task_manager_;
   Transcoder* transcoder_;
-  boost::shared_ptr<MusicStorage> destination_;
+  std::shared_ptr<MusicStorage> destination_;
   QList<Song::FileType> supported_filetypes_;
 
   const OrganiseFormat format_;
