@@ -18,6 +18,8 @@
 #ifndef UTILITIES_H
 #define UTILITIES_H
 
+#include <memory>
+
 #include <QColor>
 #include <QLocale>
 #include <QCryptographicHash>
@@ -25,8 +27,6 @@
 #include <QString>
 #include <QUrl>
 
-#include <boost/scoped_array.hpp>
-
 class QIODevice;
 class QMouseEvent;
 class QXmlStreamReader;
@@ -159,7 +159,7 @@ private:
   Q_DISABLE_COPY(ScopedWCharArray);
 
   int chars_;
-  boost::scoped_array<wchar_t> data_;
+  std::unique_ptr<wchar_t[]> data_;
 };
 
 #endif // UTILITIES_H
