@@ -18,6 +18,8 @@
 #ifndef GSTENGINEPIPELINE_H
 #define GSTENGINEPIPELINE_H
 
+#include <memory>
+
 #include <QBasicTimer>
 #include <QFuture>
 #include <QMutex>
@@ -27,7 +29,6 @@
 #include <QUrl>
 
 #include <gst/gst.h>
-#include <boost/scoped_ptr.hpp>
 
 #include "engine_fwd.h"
 
@@ -253,7 +254,7 @@ class GstEnginePipeline : public QObject {
   int volume_percent_;
   qreal volume_modifier_;
 
-  boost::scoped_ptr<QTimeLine> fader_;
+  std::unique_ptr<QTimeLine> fader_;
   QBasicTimer fader_fudge_timer_;
   bool use_fudge_timer_;
 
