@@ -20,20 +20,23 @@
 
 #include "core/urlhandler.h"
 
+class Application;
 class DigitallyImportedServiceBase;
 
 
 class DigitallyImportedUrlHandler : public UrlHandler {
 public:
-  DigitallyImportedUrlHandler(DigitallyImportedServiceBase* service);
+  DigitallyImportedUrlHandler(Application* app, DigitallyImportedServiceBase* service);
 
   QString scheme() const;
+  QIcon icon() const;
   LoadResult StartLoading(const QUrl& url);
 
   void CancelTask();
   void LoadPlaylistFinished(QIODevice* device);
 
 private:
+  Application* app_;
   DigitallyImportedServiceBase* service_;
   int task_id_;
 
