@@ -1,7 +1,7 @@
 #ifndef NETWORKREMOTE_H
 #define NETWORKREMOTE_H
 
-#include <boost/scoped_ptr.hpp>
+#include <memory>
 
 #include <QTcpServer>
 #include <QTcpSocket>
@@ -26,12 +26,14 @@ public slots:
   void StartServer();
   void ReloadSettings();
   void AcceptConnection();
+  void EnableKittens(bool aww);
+  void SendKitten(quint64 id, const QImage& kitten);
 
 private:
-  boost::scoped_ptr<QTcpServer> server_;
-  boost::scoped_ptr<QTcpServer> server_ipv6_;
-  boost::scoped_ptr<IncomingDataParser> incoming_data_parser_;
-  boost::scoped_ptr<OutgoingDataCreator> outgoing_data_creator_;
+  std::unique_ptr<QTcpServer> server_;
+  std::unique_ptr<QTcpServer> server_ipv6_;
+  std::unique_ptr<IncomingDataParser> incoming_data_parser_;
+  std::unique_ptr<OutgoingDataCreator> outgoing_data_creator_;
 
   quint16 port_;
   bool use_remote_;
