@@ -33,6 +33,7 @@ const quint32 OutgoingDataCreator::kFileChunkSize = 100000; // in Bytes
 
 OutgoingDataCreator::OutgoingDataCreator(Application* app)
   : app_(app),
+    aww_(false),
     ultimate_reader_(new UltimateLyricsReader(this)),
     fetcher_(new SongInfoFetcher(this))
 {
@@ -314,21 +315,26 @@ void OutgoingDataCreator::SendFirstData(bool send_playlist_songs) {
 void OutgoingDataCreator::CurrentSongChanged(const Song& song, const QString& uri, const QImage& img) {
   current_song_  = song;
   current_uri_   = uri;
-  current_image_ = img;
 
-  if (!clients_->empty()) {
-    // Create the message
-    pb::remote::Message msg;
-    msg.set_type(pb::remote::CURRENT_METAINFO);
-
-    // If there is no song, create an empty node, otherwise fill it with data
-    int i = app_->playlist_manager()->active()->current_row();
-    CreateSong(
-        current_song_, img, i,
-        msg.mutable_response_current_metadata()->mutable_song_metadata());
-
-    SendDataToClients(&msg);
+  if (!aww_) {
+    current_image_ = img;
   }
+
+  SendSongMetadata();
+}
+
+void OutgoingDataCreator::SendSongMetadata() {
+  // Create the message
+  pb::remote::Message msg;
+  msg.set_type(pb::remote::CURRENT_METAINFO);
+
+  // If there is no song, create an empty node, otherwise fill it with data
+  int i = app_->playlist_manager()->active()->current_row();
+  CreateSong(
+      current_song_, current_image_, i,
+      msg.mutable_response_current_metadata()->mutable_song_metadata());
+
+  SendDataToClients(&msg);
 }
 
 void OutgoingDataCreator::CreateSong(
@@ -509,11 +515,16 @@ void OutgoingDataCreator::UpdateTrackPosition() {
   pb::remote::Message msg;
   msg.set_type(pb::remote::UPDATE_TRACK_POSITION);
 
-  const int position = std::floor(
+  int position = std::floor(
     float(app_->player()->engine()->position_nanosec()) / kNsecPerSec + 0.5);
 
+  if (app_->player()->engine()->position_nanosec() > current_song_.length_nanosec())
+    position = last_track_position_;
+
   msg.mutable_response_update_track_position()->set_position(position);
 
+  last_track_position_ = position;
+
   SendDataToClients(&msg);
 }
 
@@ -628,10 +639,6 @@ void OutgoingDataCreator::SendSingleSong(RemoteClient* client, const Song &song,
   if (!(song.url().scheme() == "file"))
     return;
 
-  // Calculate the number of chunks
-  int chunk_count  = qRound((song.filesize() / kFileChunkSize) + 0.5);
-  int chunk_number = 1;
-
   // Open the file
   QFile file(song.url().toLocalFile());
   file.open(QIODevice::ReadOnly);
@@ -643,6 +650,10 @@ void OutgoingDataCreator::SendSingleSong(RemoteClient* client, const Song &song,
 
   QImage null_image;
 
+  // Calculate the number of chunks
+  int chunk_count  = qRound((file.size() / kFileChunkSize) + 0.5);
+  int chunk_number = 1;
+
   while (!file.atEnd()) {
     // Read file chunk
     data = file.read(kFileChunkSize);
@@ -726,7 +737,7 @@ void OutgoingDataCreator::SendLibrary(RemoteClient *client) {
   app_->database()->AttachDatabaseOnDbConnection("songs_export", adb, db);
 
   // Copy the content of the song table to this temporary database
-  QSqlQuery q(QString("create table songs_export.songs as SELECT * FROM songs;"), db);
+  QSqlQuery q(QString("create table songs_export.songs as SELECT * FROM songs where unavailable = 0;"), db);
 
   if (app_->database()->CheckErrors(q)) return;
 
@@ -769,3 +780,15 @@ void OutgoingDataCreator::SendLibrary(RemoteClient *client) {
   // Remove temporary file
   file.remove();
 }
+
+void OutgoingDataCreator::EnableKittens(bool aww) {
+  aww_ = aww;
+}
+
+void OutgoingDataCreator::SendKitten(const QImage& kitten) {
+  if (aww_) {
+    current_image_ = kitten;
+    SendSongMetadata();
+  }
+}
+
