@@ -23,8 +23,6 @@
 #include <QXmlStreamReader>
 #include <QXmlStreamWriter>
 
-#include <boost/noncopyable.hpp>
-
 class QDomDocument;
 class QDomNode;
 
@@ -32,7 +30,7 @@ class XMLParser : public ParserBase {
  protected:
   XMLParser(LibraryBackendInterface* library, QObject* parent);
 
-  class StreamElement : public boost::noncopyable {
+  class StreamElement {
    public:
     StreamElement(const QString& name, QXmlStreamWriter* stream) : stream_(stream) {
       stream->writeStartElement(name);
@@ -44,6 +42,7 @@ class XMLParser : public ParserBase {
 
    private:
     QXmlStreamWriter* stream_;
+    Q_DISABLE_COPY(StreamElement);
   };
 };
 
