@@ -18,9 +18,9 @@
 #ifndef ECHONESTBIOGRAPHIES_H
 #define ECHONESTBIOGRAPHIES_H
 
-#include "songinfoprovider.h"
+#include <memory>
 
-#include <boost/shared_ptr.hpp>
+#include "songinfoprovider.h"
 
 class QNetworkReply;
 
@@ -40,7 +40,7 @@ private:
   QMap<QString, QIcon> site_icons_;
 
   struct Request;
-  typedef boost::shared_ptr<Request> RequestPtr;
+  typedef std::shared_ptr<Request> RequestPtr;
 
   QMap<QNetworkReply*, RequestPtr> requests_;
 };
