@@ -17,6 +17,33 @@
 
 #include "mainwindow.h"
 #include "ui_mainwindow.h"
+
+#include <cmath>
+#include <memory>
+
+#include <QCloseEvent>
+#include <QDir>
+#include <QFileDialog>
+#include <QFileSystemModel>
+#include <QLinearGradient>
+#include <QMenu>
+#include <QMessageBox>
+#include <QSettings>
+#include <QShortcut>
+#include <QSignalMapper>
+#include <QSortFilterProxyModel>
+#include <QStatusBar>
+#include <QtDebug>
+#include <QTimer>
+#include <QUndoStack>
+
+#ifdef Q_OS_WIN32
+# include <qtsparkle/Updater>
+#endif
+
+#include <gst/cdda/gstcddabasesrc.h>
+
+
 #include "core/appearance.h"
 #include "core/application.h"
 #include "core/backgroundstreams.h"
@@ -58,6 +85,7 @@
 #include "library/libraryfilterwidget.h"
 #include "library/libraryviewcontainer.h"
 #include "musicbrainz/tagfetcher.h"
+#include "networkremote/networkremote.h"
 #include "playlist/playlistbackend.h"
 #include "playlist/playlist.h"
 #include "playlist/playlistlistcontainer.h"
@@ -117,34 +145,6 @@
 # include "moodbar/moodbarproxystyle.h"
 #endif
 
-#include <QCloseEvent>
-#include <QDir>
-#include <QFileDialog>
-#include <QFileSystemModel>
-#include <QLinearGradient>
-#include <QMenu>
-#include <QMessageBox>
-#include <QSettings>
-#include <QShortcut>
-#include <QSignalMapper>
-#include <QSortFilterProxyModel>
-#include <QStatusBar>
-#include <QtDebug>
-#include <QTimer>
-#include <QUndoStack>
-
-#ifdef Q_OS_WIN32
-# include <qtsparkle/Updater>
-#endif
-
-
-#include <cmath>
-
-#include <gst/cdda/gstcddabasesrc.h>
-
-using boost::shared_ptr;
-using boost::scoped_ptr;
-
 #ifdef Q_OS_DARWIN
 // Non exported mac-specific function.
 void qt_mac_set_dock_menu(QMenu*);
@@ -174,18 +174,8 @@ MainWindow::MainWindow(Application* app,
     device_view_(new DeviceView(this)),
     song_info_view_(new SongInfoView(this)),
     artist_info_view_(new ArtistInfoView(this)),
-    settings_dialog_(NULL),
-    cover_manager_(NULL),
     equalizer_(new Equalizer),
-    error_dialog_(NULL),
     organise_dialog_(new OrganiseDialog(app_->task_manager())),
-    queue_manager_(NULL),
-#ifdef ENABLE_VISUALISATIONS
-    visualisation_(NULL),
-#endif
-#ifdef HAVE_WIIMOTEDEV
-    wiimotedev_shortcuts_(NULL),
-#endif
     playlist_menu_(new QMenu(this)),
     playlist_add_to_another_(NULL),
     playlistitem_actions_separator_(NULL),
@@ -670,6 +660,7 @@ MainWindow::MainWindow(Application* app,
           SLOT(NowPlayingWidgetPositionChanged(bool)));
   connect(ui_->action_hypnotoad, SIGNAL(toggled(bool)), ui_->now_playing, SLOT(AllHail(bool)));
   connect(ui_->action_kittens, SIGNAL(toggled(bool)), ui_->now_playing, SLOT(EnableKittens(bool)));
+  connect(ui_->action_kittens, SIGNAL(toggled(bool)), app_->network_remote(), SLOT(EnableKittens(bool)));
   // Hide the console
   //connect(ui_->action_console, SIGNAL(triggered()), SLOT(ShowConsole()));
   NowPlayingWidgetPositionChanged(ui_->now_playing->show_above_status_bar());
@@ -1907,7 +1898,7 @@ void MainWindow::PlaylistDelete() {
         QMessageBox::Yes, QMessageBox::Cancel) != QMessageBox::Yes)
     return;
 
-  boost::shared_ptr<MusicStorage> storage(new FilesystemMusicStorage("/"));
+  std::shared_ptr<MusicStorage> storage(new FilesystemMusicStorage("/"));
 
   // Get selected songs
   SongList selected_songs;
